@@ -1,7 +1,7 @@
 """
 __init__ de mi paquete
 """
-from myWebKraken_package.myWebKraken import mAppKraken
+from myWebKraken_package.myWebKraken import myAppKraken
 from myWebKraken_package.myKrakenAPI import obtenerDatosKraken
 from myWebKraken_package.myKrakenAPI import intervalosValidos
 from myWebKraken_package.myKrakenAPI import incorporaMetricasMoviles
